/**
 * Copyright (c) 2025 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#include "physics.h"

collisionresult_t physicsCheckCircleCircle(
  fixed248_t circle0x, fixed248_t circle0y, fixed248_t circle0r,
  fixed248_t circle1x, fixed248_t circle1y, fixed248_t circle1r
) {
  collisionresult_t result;
  // Compute vector between centers
  fixed248_t dx = fx248Subfx248(circle1x, circle0x);
  fixed248_t dy = fx248Subfx248(circle1y, circle0y);

  // Distance squared between centers
  fixed248_t distSq = fx248Addfx248(
    fx248Mulfx248(dx, dx),
    fx248Mulfx248(dy, dy)
  );

  // Sum of radii
  fixed248_t rSum = fx248Addfx248(circle0r, circle1r);
  fixed248_t rSumSq = fx248Mulfx248(rSum, rSum);

  if(distSq > rSumSq) {
    // No collision
    result.hit = false;
    return result;
  }

  // Collision: calculate normal and penetration depth
  fixed248_t dist = fx248Sqrt(distSq);

  // If centers are the same, pick arbitrary normal (1,0)
  if(dist == 0) {
    result.normalX = FIXED248(1,0);
    result.normalY = 0;
    result.depth = rSum;
  } else {
    // Normalized direction from circle0 to circle1
    result.normalX = fx248Divfx248(dx, dist);
    result.normalY = fx248Divfx248(dy, dist);
    // Penetration depth = sum of radii - distance
    result.depth = fx248Subfx248(rSum, dist);
  }
  result.hit = true;
  return result;
}