/**
 * Copyright (c) 2025 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#pragma once
#include "util/fixed.h"

typedef struct {
  bool_t hit;
  fixed248_t normalX, normalY;
  fixed248_t depth;
} collisionresult_t;

/**
 * Check for collision between two circles.
 * 
 * @param circle0x X coordinate of the first circle's center.
 * @param circle0y Y coordinate of the first circle's center.
 * @param circle0r Radius of the first circle.
 * @param circle1x X coordinate of the second circle's center.
 * @param circle1y Y coordinate of the second circle's center.
 * @param circle1r Radius of the second circle.
 * @return A collisionresult_t structure containing collision information.
 */
collisionresult_t physicsCheckCircleCircle(
  fixed248_t circle0x, fixed248_t circle0y, fixed248_t circle0r,
  fixed248_t circle1x, fixed248_t circle1y, fixed248_t circle1r
);